Learn R Programming

pRoloc (version 1.12.3)

filterMinMarkers: Removes class/annotation information from a matrix of candidate markers that appear in the fData.

Description

Removes annotation information that contain less that a certain number/percentage of proteins

Usage

filterMinMarkers(object, n = 10, p, fcol = "GOAnnotations",
  verbose = TRUE)

Arguments

object
An instance of class MSnSet.
n
Minimum number of proteins allowed per column. Default is 10.
p
Minimum percentage of proteins per column.
fcol
The name of the matrix of marker information. Default is GOAnnotations.
verbose
Number of marker candidates retained after filtering.

Value

  • An updated MSnSet.

See Also

addGoAnnotations and example therein.