Learn R Programming

pRoloc (version 1.12.3)

showGOEvidenceCodes: GO Evidence Codes

Description

This function prints a textual description of the Gene Ontology evidence codes.

Usage

showGOEvidenceCodes()

getGOEvidenceCodes()

Arguments

Value

  • These functions are used for their side effects of printing evidence codes and their description.

Examples

Run this code
showGOEvidenceCodes()
getGOEvidenceCodes()

Run the code above in your browser using DataLab