Tests if the marker class sizes are large enough for the parameter
optimisation scheme, i.e. the size is greater that xval + n,
where the default xval is 5 and n is 2. If the test
is unsuccessful, a warning is thrown.
The number cross-validation partitions. See the
xval argument in the parameter optimisation function(s).
Default is 5.
n
Number of additional examples.
fcol
The name of the prediction column in the
featureData slot. Default is "markers".
error
A logical specifying if an error should be
thown, instead of a warning.
Value
If successfull, the test invisibly returns NULL. Else,
it invisibly returns the names of the classes that have too few examples.
Details
In case the test indicates that a class contains too few examples,
it is advised to either add some or, if not possible, to remove
the class altogether (see minMarkers)
as the parameter optimisation is likely to fail or, at least,
produce unreliable results for that class.